aacrepair package
=================

Submodules
----------

aacrepair.audio\_conf module
----------------------------

.. automodule:: aacrepair.audio_conf
   :members:
   :undoc-members:
   :show-inheritance:

aacrepair.cmd module
--------------------

.. automodule:: aacrepair.cmd
   :members:
   :undoc-members:
   :show-inheritance:

aacrepair.crc module
--------------------

.. automodule:: aacrepair.crc
   :members:
   :undoc-members:
   :show-inheritance:

aacrepair.dev\_aac module
-------------------------

.. automodule:: aacrepair.dev_aac
   :members:
   :undoc-members:
   :show-inheritance:

aacrepair.haeder\_mp4 module
----------------------------

.. automodule:: aacrepair.haeder_mp4
   :members:
   :undoc-members:
   :show-inheritance:

aacrepair.header\_aac module
----------------------------

.. automodule:: aacrepair.header_aac
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aacrepair
   :members:
   :undoc-members:
   :show-inheritance:
